# pyMetaModel
migrates https://wiki.bitplan.com/index.php/MetaModel#tab=Model to python

[![Join the discussion at https://github.com/WolfgangFahl/pyMetaModel/discussions](https://badges.gitter.im/pyMetaModel/community.svg)](https://github.com/WolfgangFahl/pyMetaModel/discussions)
[![pypi](https://img.shields.io/pypi/pyversions/pyMetaModel)](https://pypi.org/project/pyMetaModel/)
[![Github Actions Build](https://github.com/WolfgangFahl/pyMetaModel/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/pyMetaModel/actions?query=workflow%3ABuild+branch%3Amain)
[![PyPI Status](https://img.shields.io/pypi/v/pyMetaModel.svg)](https://pypi.python.org/pypi/pyMetaModel/)
[![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pyMetaModel.svg)](https://github.com/WolfgangFahl/pyMetaModel/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pyMetaModel.svg)](https://github.com/WolfgangFahl/pyMetaModel/issues/?q=is%3Aissue+is%3Aclosed)
[![License](https://img.shields.io/github/license/WolfgangFahl/pyMetaModel.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Introduction
pyMetaModel is a python library that started with the ProfiWiki [SemanticMediaWiki MetaModel](https://wiki.bitplan.com/index.php/MetaModel#tab=topics) in
2015 consisting of

- Context
- Topic
- TopicLink
- Property
- Action
- SMWType
